@@ -1,5 +1,5 @@
-from skoopy import get_all_books
-from skoopy import save_desired_csv
+from skoobpy import get_all_books
+from skoobpy import save_desired_csv
 
 def main():
     from sys import argv
